`smore.apispec`: Pluggable API Documentation Generator
======================================================

.. automodule:: smore.apispec.core
    :members:

.. automodule:: smore.apispec.exceptions
    :members:
